''' 
  BA_Exaggeration_v2bqt
  a added functionality of
  choice between G'mic 1.7.6-8, 1.7.9, 2.0.0 or 2.0.0QT
  b fixed an intermittant resize issue where height
    was being compressed.

  Filter uses GMIC ver 1.7.6-8, 1.7.9 or 2.0.0 at this time.
  will not work using any other known version of GMIC.
  Some presets are included for entertainment.
  Based on a flomboyant flow by Lylejk on GimpChat
  By Brian Andersen (animicule@gimpchat.com)
  March, 2017.
  Filter developed on Windows 7 64bit and Gimp Version 2.8.16

 ...................................................... 
 ----------------------------------------------------------------
 COPYRIGHT NOTICE
 ----------------------------------------------------------------
 You can view the GNU General Public
 License version 3 at the web site http://www.gnu.org/licenses/gpl-3.0.html
 Alternatively you can write to the Free Software Foundation, Inc., 675 Mass
 Ave, Cambridge, MA 02139, USA.
 ___________________________________________________________________

 -------------------------------------------------------------------
'''
#!/usr/bin/env python
from gimpfu import *
import decimal

def BA_Exaggeration_v2bqt(inImage, inDrawable, GmicVer, intensity, shine, 
                      doublesize, targetwidth, ): 

    pdb.gimp_context_push
    pdb.gimp_context_set_interpolation(INTERPOLATION_LANCZOS) 
    
    width      = inImage.width
    height    = inImage.height
    type   = inImage.base_type
    intensity = int(intensity)
    targetw = int(targetwidth)
    TargetW = 0    

# create name string for file export 
    name = inDrawable.name
    if '.' in name:
        split = name.split(".", 1)
        name = split[0]
    suffix = "_BA_Exaggeration_v2a"

    Gmic176=Gmic179=Gmic200=Gmic200qt=False
    if GmicVer == 0:
        Gmic176 = True
    elif GmicVer == 1:
        Gmic179 = True
    elif GmicVer == 2:
        Gmic200 = True
    elif GmicVer == 3:
        Gmic200qt = True
    else:
        pdb.gimp_message("<<< USER ERROR >>>\nDID NOT CHOOSE G'MIC VERSION\nSCRIPT ENDED")
        return()

        
# calculate the process size 
    if targetw > 0:
        TargetW = targetw*250
    if doublesize:
        TargetW = TargetW * 2
    if TargetW == 0:
        scale = 1
    else:
        scale = decimal.Decimal(TargetW)/decimal.Decimal(width)
    
    processwidth =int(width *scale)
    processheight=int(height*scale)
    
# create subject layer, scale
    newImage = pdb.gimp_image_new (processwidth, processheight, type)
    
    origBG = pdb.gimp_layer_new_from_drawable(inDrawable, newImage) 
    origBG.mode = NORMAL_MODE
    origBG.name = name+suffix
    origBG.opacity = 100.0 
    newImage.add_layer (origBG, 0)
    pdb.gimp_item_set_visible(origBG, False) # visiblity off for merge visible   
    pdb.gimp_layer_scale(origBG, processwidth, processheight, False)
    alpha=pdb.gimp_drawable_has_alpha(origBG)
    if (alpha==False):
        pdb.gimp_layer_add_alpha (origBG)    #  RGBA
   
# dup subject layer to top with name 'temp convolution' set visible for merge visible
    tempoLay = origBG.copy()
    tempoLay.mode = NORMAL_MODE
    tempoLay.name = "Temp Convolution"
    tempoLay.opacity = 100.0 
    newImage.add_layer(tempoLay, 0)
    pdb.gimp_item_set_visible(tempoLay, True)   

# dup subject layer to top, smooth bilateral, set visible for merge visible
    bilatLay = origBG.copy()
    bilatLay.mode = NORMAL_MODE
    bilatLay.name = "Temp BiLateral"
    bilatLay.opacity = 100.0 
    newImage.add_layer(bilatLay, 0)
    pdb.gimp_item_set_visible(bilatLay, True)
    # [G'MIC] Smooth [bilateral]: -gimp_smooth_bilateral 10,12,2,0,0
    if Gmic176:
        pdb.plug_in_gmic(newImage,bilatLay, 1,    # 1 = apply to active layer only
        "-v - -gimp_bilateral 10,12,2,0,0")
    if Gmic179:
        pdb.plug_in_gmic(newImage, bilatLay, 1,    # 1=input only active layer
        "-v - -gimp_smooth_bilateral 10,12,2,0,0")
    if Gmic200:
        pdb.plug_in_gmic2(newImage, bilatLay, 1,    # 1=input only active layer
        "-v - -fx_smooth_bilateral 10,12,2,0,0")
    if Gmic200qt:
        pdb.plug_in_gmic_qt(newImage, bilatLay, 1,0,    # 1=input only active layer
        "-v - -fx_smooth_bilateral 10,12,2,0,0")
    bilatLay.mode = GRAIN_EXTRACT_MODE
    
# merge bilateral smoothed Grain Extract Mode layer into convolution layer
    mergeLay=pdb.gimp_image_merge_down(newImage, bilatLay, 0)
    mergeLay.name = "Temp2 Convolution"    
    
# Loop -- set to grain merge and duplicate selected # of times 
    intensityCnt=0
    while (intensityCnt < intensity):
        TMPLayer = 'merge'+str(intensityCnt)  
        TMPLayer = mergeLay.copy()
        TMPLayer.mode = GRAIN_MERGE_MODE
        TMPLayer.opacity = 100.0 
        newImage.add_layer(TMPLayer, 0)
        pdb.gimp_item_set_visible(TMPLayer, True)
        intensityCnt=intensityCnt+1
       
# set Subject not visible &  merge all visible layers into convo layer
    pdb.gimp_item_set_visible(origBG, False)
    convoLay=pdb.gimp_image_merge_visible_layers(newImage, 1)
    convoLay.mode = GRAIN_MERGE_MODE
    convoLay.name = "Convolution"
    convoLay.opacity = 100.0

#[G'MIC] Smooth [anisotropic]: -gimp_smooth_anisotropic 150,0.42,0.85,0.6,7.83,0.68,19.07,2.64,0,1,1,0,0 
    if Gmic176:
        pdb.plug_in_gmic(newImage,convoLay, 1,    # 1 = apply to active layer only
        "-v - -gimp_anisotropic_smoothing 150,0.42,0.85,0.6,7.83,0.68,19.07,2.64,0,1,1,0,0") 
    if Gmic179:
        pdb.plug_in_gmic(newImage, convoLay, 1,    # 1=input only active layer
        "-v - -gimp_smooth_anisotropic 150,0.42,0.85,0.6,7.83,0.68,19.07,2.64,0,1,1,0,0")
    if Gmic200:
        pdb.plug_in_gmic2(newImage, convoLay, 1,    # 1=input only active layer
        "-v - -fx_smooth_anisotropic 150,0.42,0.85,0.6,7.83,0.68,19.07,2.64,0,1,1,0,0")
    if Gmic200qt:
        pdb.plug_in_gmic_qt(newImage, convoLay, 1,0,    # 1=input only active layer
        "-v - -fx_smooth_anisotropic 150,0.42,0.85,0.6,7.83,0.68,19.07,2.64,0,1,1,0,0")

    convoLay = pdb.gimp_image_get_active_layer(newImage)
    if Gmic176 or Gmic179:
        pdb.plug_in_gmic(newImage, convoLay, 1,
        "-v - -gimp_freaky_details 3,12.6697,3,22,0,151,0")
    if Gmic200:
        pdb.plug_in_gmic2(newImage, convoLay, 1,
        "-v - -fx_freaky_details 3,12.6697,3,22,0,151,0")
    if Gmic200qt:
        pdb.plug_in_gmic_qt(newImage, convoLay, 1,0,
        "-v - -fx_freaky_details 3,12.6697,3,22,0,151,0")
    if shine:
        if Gmic176 or Gmic179:
            pdb.plug_in_gmic(newImage, convoLay, 1,
            "-v - -gimp_contrast_swm 2,1,1")
        if Gmic200:
            pdb.plug_in_gmic2(newImage, convoLay, 1,
            "-v - -fx_contrast_swm 2,1,1")
        if Gmic200qt:
            pdb.plug_in_gmic2(newImage, convoLay, 1,0,
            "-v - -fx_contrast_swm 2,1,1")
    convoLay.name = "Convolution" 

# copy original subject to top of stack in hue 100%
    oriSUB = origBG.copy()
    oriSUB.mode = HUE_MODE
    oriSUB.name = "Subject Hue"
    oriSUB.opacity = 100.0 
    newImage.add_layer(oriSUB, 0)
    pdb.gimp_item_set_visible(oriSUB, True)   
    pdb.gimp_item_set_visible(origBG, True)

# new from visible from the 1st 3 layers
    visONE = pdb.gimp_layer_new_from_visible(newImage,newImage, 'Visible Color')
    newImage.add_layer(visONE, 0) 
    visONE.mode = COLOR_MODE
    visONE.opacity = 100.0
    pdb.gimp_item_set_visible(visONE, True)

# new from visible copy for the next G'mic
    fdLay = visONE.copy()
    fdLay.mode = SOFTLIGHT_MODE
    fdLay.name = 'Details'
    fdLay.opacity  = 100.0
    newImage.add_layer(fdLay)
    pdb.gimp_item_set_visible(fdLay, True)

# run FD on new layer
    if Gmic176 or Gmic179:
        pdb.plug_in_gmic(newImage, fdLay, 1,
        "-v - -gimp_freaky_details 2,10,1,11,0,32,0")
    if Gmic200:
        pdb.plug_in_gmic2(newImage, fdLay, 1,
        "-v - -fx_freaky_details 2,10,1,11,0,32,0")
    if Gmic200qt:
        pdb.plug_in_gmic_qt(newImage, fdLay, 1,0,
        "-v - -fx_freaky_details 2,10,1,11,0,32,0")
    pdb.gimp_item_set_visible(fdLay, True)

# new from FD layer for the next G'mic
    hbLay = fdLay.copy()
    if shine:
        hbLay.mode = BURN_MODE
        hbLay.name = 'Burn'
    else:
        hbLay.mode = SCREEN_MODE
        hbLay.name = 'Screen'
    hbLay.opacity = 100.0
    newImage.add_layer(hbLay)
    pdb.gimp_item_set_visible(hbLay, True)

# run HB on new layer (not avail in 176)
    if Gmic176:
        pdb.plug_in_gmic(newImage, hbLay, 1,
        "-v - -gimp_mighty_details 25,1,25,1,11,0")
    if Gmic179:
        pdb.plug_in_gmic(newImage, hbLay, 1,
        "-v - -gimp_highlight_bloom 90,60,60,30,20,0")
    if Gmic200:
        pdb.plug_in_gmic2(newImage, hbLay, 1,
        "-v - -fx_highlight_bloom 90,60,60,30,20,0")
    if Gmic200qt:
        pdb.plug_in_gmic_qt(newImage, hbLay, 1,0,
        "-v - -fx_highlight_bloom 90,60,60,30,20,0")
#  make value layer    
    valLay = oriSUB.copy()
    if shine:
        convoLay.mode = BURN_MODE  #added late at night
        valLay.mode = SCREEN_MODE
        valLay.name = 'Screen'     #changed from Shine late at night
    else:
        valLay.mode = MULTIPLY_MODE
        valLay.name = 'Multiply'
    valLay.opacity = 100.0
    newImage.add_layer(valLay)
    pdb.gimp_item_set_visible(valLay, True)

    # scale image back to original
    pdb.gimp_image_scale(newImage,inImage.width,inImage.height)

    # send new image to display    
    pdb.gimp_display_new (newImage)    
    
    # Close the undo group ?
    pdb.gimp_displays_flush
    pdb.gimp_context_pop
    
    return(BA_Exaggeration_v2bqt)

# This is the plugin registration function
register(
    "BA_Exaggeration_v2bqt",    
    "BA_Exaggeration uses G'Mic 1.7.9,2.0.0 or 2.0.0qt  ~\nRemember: Select your G'Mic Version \nSmaller process size = Looser pattern\nLarger Process Size = Tighter pattern",     
    "Incompatible with earlier versions",
    "animicule@gimpchat.com", 
    "Brian Andersen ", 
    "Feb 22 2017",
    "BA Exaggeration v2bqt", 
    "RGB*", 
    [
      (PF_IMAGE, "image", "Input image", None),
      (PF_DRAWABLE, "idrawable", "Input drawable", None),
      (PF_OPTION, "GmicVer", "Choose your G'Mic Version --->>>", 3, ("1.7.6-8", "1.7.9", "2.0.0", "2.0.0qt")),
      (PF_ADJUSTMENT, "intensity", "Convolutions (6 or 7) 1-150", 6, (1,150,1)),
      (PF_TOGGLE, "shine", "Switch modes on top 2 layers", False),
      (PF_TOGGLE, "doublesize", "Doubles Process width (if<>0)", False),
      (PF_OPTION, "targetwidth", "Process Width     0=Subject Width", 0, ("0", "250", "500", "750", "1000", "1250", 
                "1500", "1750", "2000", "2250", "2500", "2750", "3000", "3250","3500","3750","4000" )),      
      
    ], 
    [
      (PF_DRAWABLE, "odrawable", "Output drawable", None),  
    ],
    BA_Exaggeration_v2bqt,
    menu="<Image>/Brian/",
    )

main()
