''' 
  Flamboyance_PS_V5 
  
  Filter to create a Flamboyance image with few clicks.
  Based on one of Lylejk's flows from Gimp Chat.
  Thank you Lyle!
  Written by Brian Andersen (animicule@gimpchat.com)
  December 2016.
  Filter uses choice of GMIC from 1.76 to 2.0.0 only at this time.
  will not work using any other known version of GMIC.
  Some presets are included for entertainment.
  Filter developed on Windows 7 64bit and Gimp Version 2.8.16

  Version 5 replaced Rodilius option with Gmic Boost/Fade.  
  Another change, the old 2x button doubled the subject
  size for use as the process size and overrode the 
  process size selection - it has been changed to double 
  the scale of the process size selection. 
 
  Many thanks to Dinasset whose scripts have been my tutors
  and inspiration while learning to script in python.
  Also to Pat625 and Issabella for their encouragement and
  inspirations.
 ...................................................... 
 ----------------------------------------------------------------
 COPYRIGHT NOTICE
 ----------------------------------------------------------------
 You can view the GNU General Public  License version 3 at the web site 
 http://www.gnu.org/licenses/gpl-3.0.html  Alternatively you can write to 
 the Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 ___________________________________________________________________

 -------------------------------------------------------------------
'''
#!/usr/bin/env python
from gimpfu import *
import decimal

def BA_Flamboyance5aqt (inImage, inDrawable, GmicVer, intensity,
                      doublesize, targetwidth, lyleflag, lyleflag2,
                      freakflag, cboflag, embflag, fxset, modeset,): 

    pdb.gimp_context_push()
    pdb.gimp_context_set_interpolation(INTERPOLATION_LANCZOS) 
    
    width      = inImage.width
    height    = inImage.height
    type   = inImage.base_type
    intensity = int(intensity)
    ModeSet     = int(modeset)
    FXSet         = int(fxset)
    targetw = int(targetwidth)
    TargetW = 0    

# create name string for file export 
    name = inDrawable.name
    if '.' in name:
        split = name.split(".", 1)
        name = split[0]
    suffix = "BA_Flamboyance_v5aqt"

# get Gmic version

    Gmic176=Gmic179=Gmic200=Gmic220=False
    if GmicVer == 0:
        Gmic176 = True
    elif GmicVer == 1:
        Gmic179 = True
    elif GmicVer == 2:
        Gmic200 = True
    elif GmicVer == 3:
        Gmic220 = True
    else:
        pdb.gimp_message("<<< USER ERROR >>>\nDID NOT CHOOSE G'MIC VERSION\nSCRIPT ENDED")
        return()
    #gimp.message ("gmic versions = "+str(Gmic176)+", "+str(Gmic179)+", "+str(Gmic200)+", "+str(Gmic220)+". ")
# decode fx set - choice of strength on the 3 option filters
   
    if   FXSet == 0:     
        FD_bin = False #000 False = Pre  effect
        CB_bin = False #    True  = Post effect
        EB_bin = False 
    elif FXSet == 1:   #001  
        FD_bin = False
        CB_bin = False
        EB_bin = True
    elif FXSet == 2:   #010  
        FD_bin = False
        CB_bin = True
        EB_bin = False
    elif FXSet == 3:   #011  
        FD_bin = False
        CB_bin = True
        EB_bin = True		
    elif FXSet == 4:   #100 
        FD_bin = True
        CB_bin = False
        EB_bin = False
    elif FXSet == 5:   #101
        FD_bin = True
        CB_bin = False
        EB_bin = True
    elif FXSet == 6:   #110
        FD_bin = False
        CB_bin = True
        EB_bin = True
    elif FXSet == 7:   #111
        FD_bin = True 
        CB_bin = True 
        EB_bin = True  

# increments of 250 or 500 process width choice 

    if targetw > 0:
        TargetW = targetw*250
    if doublesize:
        TargetW = TargetW * 2
    if TargetW == 0:
        scale = 1
    else:
        scale = decimal.Decimal(TargetW)/decimal.Decimal(width)
    
    newwidth =int(width *scale)
    newheight=int(height*scale)
# create subject layer, scale
    newImage = pdb.gimp_image_new (newwidth, newheight, type)
    origBG = pdb.gimp_layer_new_from_drawable(inDrawable, newImage) 
    origBG.mode = NORMAL_MODE
    origBG.name = name+suffix
    origBG.opacity = 100.0 
    newImage.add_layer (origBG, 0)
    pdb.gimp_item_set_visible(origBG, 1) # visiblity off for merge visible   
    pdb.gimp_layer_scale(origBG, newwidth, newheight, False)
    alpha=pdb.gimp_drawable_has_alpha(origBG)
    if (alpha==False):
        pdb.gimp_layer_add_alpha (origBG)    #  RGBA

# dup origBG layer to top, apply hard sketch and set visible for merge visible
    sketcLay = origBG.copy()
    sketcLay.mode = NORMAL_MODE
    sketcLay.name = "HardSketch"
    sketcLay.opacity = 100.0 
    newImage.add_layer(sketcLay, 0)
    pdb.gimp_item_set_visible(sketcLay, 1)
    if Gmic176 or Gmic179:
        pdb.plug_in_gmic(newImage, sketcLay, 1,    # 1 = apply to active layer only
        "-v - -gimp_hardsketchbw 65,28,9.25,0.3,0,0,1,0")
    if Gmic200:
        pdb.plug_in_gmic2(newImage, sketcLay, 1,   # 1=input only active layer
        "-v - -fx_hardsketchbw 65,28,9.25,0.3,0,0,1,0")
    if Gmic220:
        pdb.plug_in_gmic_qt(newImage, sketcLay, 1, 0,   # 1=input only active layer
        "-v - -fx_hardsketchbw 65,28,9.25,0.3,0,0,1,0")
# dup subject layer to top with name 'temp convolution' set visible for merge visible
    tempoLay = origBG.copy()
    tempoLay.mode = NORMAL_MODE
    tempoLay.name = "Temp Convolution"
    tempoLay.opacity = 100.0 
    newImage.add_layer(tempoLay, 0)
    pdb.gimp_item_set_visible(tempoLay, 1)  
 
# dup subject layer to top, smooth bilateral, set visible for merge visible
    bilatLay = origBG.copy()
    bilatLay.mode = NORMAL_MODE
    bilatLay.name = "Temp BiLateral"
    bilatLay.opacity = 100.0 
    newImage.add_layer(bilatLay, 0)
    pdb.gimp_item_set_visible(bilatLay, 1)
    if Gmic176:
        pdb.plug_in_gmic(newImage,bilatLay, 1,    # 1 = apply to active layer only
        "-v - -gimp_bilateral 10,12,2,0,0")
    if Gmic179:
        pdb.plug_in_gmic(newImage,bilatLay, 1,    # 1 = apply to active layer only
        "-v - -gimp_smooth_bilateral 10,12,2,0,0")
    if Gmic200:
        pdb.plug_in_gmic2(newImage,bilatLay, 1,    # 1 = apply to active layer only
        "-v - -fx_smooth_bilateral 10,12,2,0,0")
    if Gmic220:
        pdb.plug_in_gmic_qt(newImage,bilatLay, 1, 0,    # 1 = apply to active layer only
        "-v - -fx_smooth_bilateral 10,12,2,0,0")
    bilatLay.mode = GRAIN_EXTRACT_MODE

# merge bilateral smoothed Grain Extract Mode layer into convolution layer
    
    mergeLay=pdb.gimp_image_merge_down(newImage, bilatLay, 0)
    mergeLay.name = "Temp2 Convolution"    
    
# Loop -- set to grain merge and duplicate selected # of times 
 
    intensityCnt=0
    while (intensityCnt < intensity):
        TMPLayer = 'merge'+str(intensityCnt)  
        TMPLayer = mergeLay.copy()
        TMPLayer.mode = GRAIN_MERGE_MODE
        TMPLayer.opacity = 100.0 
        newImage.add_layer(TMPLayer, 0)
        pdb.gimp_item_set_visible(TMPLayer, 1)
        intensityCnt=intensityCnt+1
       
# set Subject not visible &  merge all visible layers into HardSketch layer

    pdb.gimp_item_set_visible(origBG, 0)
    convoLay=pdb.gimp_image_merge_visible_layers(newImage, 1)
    convoLay.mode = GRAIN_MERGE_MODE
    convoLay.name = "Convolution"

# Apply effects on convolution layer and set Subject back to visible

    #[G'MIC]176 Smooth [anisotropic]: -gimp_anisotropic_smoothing 60,0.7,0.3,0.6,1.1,0.8,30,2,0,1,1,0,0
    #[G'MIC]200 Smooth [anisotropic]: -fx_smooth_anisotropic 150,0.42,0.85,0.6,7.83,0.68,19.07,2.64,0,1,1,0,0  
    if Gmic176:
        pdb.plug_in_gmic(newImage,convoLay, 1,    # 1 = apply to active layer only
        "-v - -gimp_anisotropic_smoothing 150,0.42,0.85,0.6,7.83,0.68,19.07,2.64,0,1,1,0,0")
    if Gmic179:
        pdb.plug_in_gmic(newImage,convoLay, 1,    # 1 = apply to active layer only
        "-v - -gimp_smooth_anisotropic 150,0.42,0.85,0.6,7.83,0.68,19.07,2.64,0,1,1,0,0")
    if Gmic200:
        pdb.plug_in_gmic2(newImage,convoLay, 1,    # 1 = apply to active layer only
        "-v - -fx_smooth_anisotropic 150,0.42,0.85,0.6,7.83,0.68,19.07,2.64,0,1,1,0,0")
    if Gmic220:
        pdb.plug_in_gmic_qt(newImage,convoLay, 1, 0,    # 1 = apply to active layer only
        "-v - -fx_smooth_anisotropic 150,0.42,0.85,0.6,7.83,0.68,19.07,2.64,0,1,1,0,0")
# cartoon right after anisotropic
    if Gmic176 or Gmic179:
        pdb.plug_in_gmic(newImage, convoLay, 1,    # 1=input only active layer
        "-v - -cartoon 3,200,20,0,1.5,8,0")
    if Gmic200:
        pdb.plug_in_gmic2(newImage, convoLay, 1,    # 1=input only active layer
        "-v - -cartoon 3,200,20,0,1.5,8,0")
    if Gmic220:
        pdb.plug_in_gmic_qt(newImage, convoLay, 1, 0,    # 1=input only active layer
        "-v - -cartoon 3,200,20,0,1.5,8,0")
    convoLay.opacity = 50.0 
    pdb.gimp_item_set_visible(origBG, 1)

# copy subject layer to top and set to lighten only mode

    lightLay = origBG.copy()
    lightLay.mode = LIGHTEN_ONLY_MODE
    lightLay.name = "SubjectLighten"
    lightLay.opacity = 100.0 
    newImage.add_layer(lightLay, 0)
    pdb.gimp_item_set_visible(lightLay, 1) 

# copy subject layer to top and set to Color

    colorLay = origBG.copy()
    colorLay.mode = COLOR_MODE
    colorLay.name = "SubjectColor"
    colorLay.opacity = 100.0 
    newImage.add_layer(colorLay, 0)
    pdb.gimp_item_set_visible(colorLay, 1)  

# create new layer from visible as new 'subject background' for optional effect layers

    visibLay=pdb.gimp_layer_new_from_visible(newImage, newImage, 'visible')
    newImage.add_layer(visibLay, 0)
    visibLay.mode = NORMAL_MODE
    visibLay.name='First Visible'
    pdb.gimp_item_set_visible(visibLay, 1)

# option of emboss true, add embossed layer to top
# filter applied with choice of strength
    if embflag:
        if EB_bin: 
            FXLayer1 =   origBG.copy()
            FXLayer1.name = 'Embossed B1'  
            FXLayer1.mode = HARDLIGHT_MODE
            FXLayer1.opacity = 50.0 
            newImage.add_layer(FXLayer1, 0)
            pdb.plug_in_emboss(newImage, FXLayer1, 30, 70, 40, 0) #emboss 0, bumpmap 1            
        else:
            FXLayer1 =   origBG.copy()
            FXLayer1.name = 'Embossed B0'
            FXLayer1.mode = HARDLIGHT_MODE
            FXLayer1.opacity = 50.0 
            newImage.add_layer(FXLayer1, 0)
            pdb.plug_in_emboss(newImage, FXLayer1, 30, 70, 10, 0) #emboss 0, bumpmap 1
        pdb.gimp_item_set_visible(FXLayer1, 1)

# option of Chroma Boost true, add filtered layer to top
# filter choice of Graphic or Chroma boost
    if cboflag:   
        if CB_bin:
            FXLayer2 =   origBG.copy()
            FXLayer2.name = 'GraphicBoost  B2'
            FXLayer2.mode = GRAIN_MERGE_MODE
            FXLayer2.opacity = 50.0 
            newImage.add_layer(FXLayer2, 0)
            if Gmic176 or Gmic179:
                pdb.plug_in_gmic(newImage,FXLayer2, 1,    # 1 = apply to active layer only
                "-v - -gimp_graphic_boost4 1.25,2,0,0.15,14,0,1,0.5,0.45,2,0,1,0,1,1,1,0.5,0.45,1")
            if Gmic200:
                pdb.plug_in_gmic2(newImage, FXLayer2, 1,    # 1=input only active layer
                "-v - -fx_graphic_boost4 1.25,2,0,0.15,14,0,1,0.5,0.45,2,0,1,0,1,1,1,0.5,0.45,1")
            if Gmic220:
                pdb.plug_in_gmic_qt(newImage, FXLayer2, 1, 0,    # 1=input only active layer
                "-v - -fx_graphic_boost4 1.25,2,0,0.15,14,0,1,0.5,0.45,2,0,1,0,1,1,1,0.5,0.45,1") 
        else:
            FXLayer2 = origBG.copy()
            FXLayer2.name = 'ChromaBoost B0'
            FXLayer2.mode = GRAIN_MERGE_MODE
            FXLayer2.opacity = 50.0 
            newImage.add_layer(FXLayer2, 0)    
            if Gmic176 or Gmic179:
                pdb.plug_in_gmic(newImage,FXLayer2, 1,    # 1 = apply to active layer only
                "-v - -gimp_boost_chroma 50,0,0")
            if Gmic200:
                pdb.plug_in_gmic2(newImage, FXLayer2, 1,    # 1=input only active layer
                "-v - -fx_boost_chroma 50.0,0,0")
            if Gmic220:
                pdb.plug_in_gmic_qt(newImage, FXLayer2, 1, 0,    # 1=input only active layer
                "-v - -fx_boost_chroma 50.0,0,0")
        pdb.gimp_item_set_visible(FXLayer2, 1)
# option of boost/fade, add filtered layer to top
# filter choice of dark or light 
    if freakflag:
        if FD_bin:
            FXLayer3 =   origBG.copy()
            FXLayer3.name = 'Boost B4'
            FXLayer3.mode = GRAIN_MERGE_MODE
            FXLayer3.opacity = 80.0 
            newImage.add_layer(FXLayer3, 0)
            if Gmic176 or Gmic179:
                pdb.plug_in_gmic(newImage, FXLayer3, 1,    # 1=input only active layer
                "-v - -gimp_boost_fade 9.6,0") 
            if Gmic200:
                pdb.plug_in_gmic2(newImage, FXLayer3, 1,    # 1=input only active layer
                "-v - -fx_boost_fade 9.6,0")
            if Gmic220:
                pdb.plug_in_gmic_qt(newImage, FXLayer3, 1, 0,    # 1=input only active layer
                "-v - -fx_boost_fade 9.6,0")
        else:
            FXLayer3 =   origBG.copy()
            FXLayer3.name = 'Fade B0'
            FXLayer3.mode = GRAIN_MERGE_MODE
            FXLayer3.opacity = 80.0 
            newImage.add_layer(FXLayer3, 0)  
            if Gmic176 or Gmic179:
                pdb.plug_in_gmic(newImage, FXLayer3, 1,    # 1=input only active layer
                "-v - -gimp_boost_fade 3.2,0")        
            if Gmic200:
                pdb.plug_in_gmic2(newImage, FXLayer3, 1,    # 1=input only active layer
                "-v - -fx_boost_fade 3.2,0")
            if Gmic220:
                pdb.plug_in_gmic_qt(newImage, FXLayer3, 1, 0,    # 1=input only active layer
                "-v - -fx_boost_fade 3.2,0")
        pdb.gimp_item_set_visible(FXLayer3, 1)
# option of Lyle Layer true, copy convoLayer to top

    if lyleflag or lyleflag2:
        LyleLay = convoLay.copy()
        LyleLay.mode = VALUE_MODE
        LyleLay.name = "Lyle Layer"
        LyleLay.opacity = 25.0 
        newImage.add_layer(LyleLay, 0)
        pdb.gimp_item_set_visible(LyleLay, 1) 
    if lyleflag2:
        LyleLay2 = convoLay.copy()
        LyleLay2.mode = GRAIN_EXTRACT_MODE
        LyleLay2.name = "Lyle2 Layer"
        LyleLay2.opacity = 40.0 
        newImage.add_layer(LyleLay2, 0)
        pdb.gimp_invert(LyleLay2)
        pdb.gimp_item_set_visible(LyleLay, 1)   
######################################################################################
#######################   MODES ######################################################
######################################################################################
    if ModeSet == 0:
        None
    elif ModeSet == 1: ###############################################################
        if cboflag:   
            pdb.gimp_image_remove_layer(newImage, FXLayer2) 
        FXLayer2 =   origBG.copy()
        FXLayer2.name = 'GraphicBoost  B2'
        FXLayer2.mode = GRAIN_MERGE_MODE
        FXLayer2.opacity = 25.0 
        newImage.add_layer(FXLayer2, 0)  
        if Gmic176 or Gmic179:
            pdb.plug_in_gmic(newImage, FXLayer2, 1,    # 1=input only active layer
            "-v - -gimp_graphic_boost4 1.25,2,0,0.15,14,0,1,0.5,0.45,2,0,1,0,1,1,1,0.5,0.45,1")
        if Gmic200:
            pdb.plug_in_gmic2(newImage, FXLayer2, 1,    # 1=input only active layer
            "-v - -fx_graphic_boost4 1.25,2,0,0.15,14,0,1,0.5,0.45,2,0,1,0,1,1,1,0.5,0.45,1")
        if Gmic220:
            pdb.plug_in_gmic_qt(newImage, FXLayer2, 1, 0,    # 1=input only active layer
            "-v - -fx_graphic_boost4 1.25,2,0,0.15,14,0,1,0.5,0.45,2,0,1,0,1,1,1,0.5,0.45,1")
        FXLayer2a = origBG.copy()
        FXLayer2a.name = 'ChromaBoost B0'
        FXLayer2a.mode = GRAIN_MERGE_MODE
        FXLayer2a.opacity = 75.0 
        newImage.add_layer(FXLayer2a, 0)  
        if Gmic176 or Gmic179:
            pdb.plug_in_gmic(newImage, FXLayer2a, 1,    # 1=input only active layer
            "-v - -gimp_boost_chroma 50.0,0,0")
        if Gmic200:
            pdb.plug_in_gmic2(newImage, FXLayer2a, 1,    # 1=input only active layer
            "-v - -fx_boost_chroma 50.0,0,0")
        if Gmic220:
            pdb.plug_in_gmic_qt(newImage, FXLayer2a, 1, 0,    # 1=input only active layer
            "-v - -fx_boost_chroma 50.0,0,0")
        if not lyleflag:
            LyleLay = convoLay.copy()
            LyleLay.mode = VALUE_MODE
            LyleLay.name = "Lyle Layer"
            LyleLay.opacity = 18.0 
            newImage.add_layer(LyleLay, 0)
        pdb.gimp_item_set_visible(LyleLay, 1)            
        pdb.gimp_image_raise_layer_to_top(newImage, LyleLay)

    elif ModeSet == 2:     ###########################################################
        if embflag:
            FXLayer1.mode = GRAIN_MERGE_MODE
        if cboflag:
            pdb.gimp_image_remove_layer(newImage, FXLayer2) 
        FXLayer2 =   origBG.copy()
        FXLayer2.name = 'GraficBoost  B0'
        FXLayer2.mode = GRAIN_MERGE_MODE
        FXLayer2.opacity = 10.0 
        newImage.add_layer(FXLayer2, 0)  
        if Gmic176 or Gmic179:
            pdb.plug_in_gmic(newImage, FXLayer2, 1,    # 1=input only active layer
            "-v - -gimp_graphic_boost4 1.25,2,0,0.15,14,0,1,0.5,0.45,2,0,1,0,1,1,1,0.5,0.45,1")
        if Gmic200:
            pdb.plug_in_gmic2(newImage, FXLayer2, 1,    # 1=input only active layer
            "-v - -fx_graphic_boost4 1.25,2,0,0.15,14,0,1,0.5,0.45,2,0,1,0,1,1,1,0.5,0.45,1")
        if Gmic220:
            pdb.plug_in_gmic_qt(newImage, FXLayer2, 1, 0,    # 1=input only active layer
            "-v - -fx_graphic_boost4 1.25,2,0,0.15,14,0,1,0.5,0.45,2,0,1,0,1,1,1,0.5,0.45,1")
        FXLayer2a = origBG.copy()
        FXLayer2a.name = 'ChromaBoost B1'
        FXLayer2a.mode = GRAIN_MERGE_MODE
        FXLayer2a.opacity = 25.0 
        newImage.add_layer(FXLayer2a, 0)  
        if Gmic176 or Gmic179:
            pdb.plug_in_gmic(newImage, FXLayer2a, 1,    # 1=input only active layer
            "-v - -gimp_boost_chroma 70.0,0,0")
        if Gmic200:
            pdb.plug_in_gmic2(newImage, FXLayer2a, 1,    # 1=input only active layer
            "-v - -fx_boost_chroma 70.0,0,0")
        if Gmic200:
            pdb.plug_in_gmic_qt(newImage, FXLayer2a, 1, 0,    # 1=input only active layer
            "-v - -fx_boost_chroma 70.0,0,0")
        if not lyleflag: 
            LyleLay = convoLay.copy()
            LyleLay.mode = OVERLAY_MODE
            newImage.add_layer(LyleLay, 0)
            pdb.gimp_item_set_visible(LyleLay, 1)
        LyleLay.name = "25% Lyle_Layer1"
        LyleLay.opacity = 40.0
        pdb.gimp_image_raise_layer_to_top(newImage, LyleLay) 
        if lyleflag2:
            pdb.gimp_image_remove_layer(newImage,LyleLay2)
        LyleLay2 = convoLay.copy()    
        LyleLay2.mode = OVERLAY_MODE
        LyleLay2.name = "10% Lyle Layer2"
        LyleLay2.opacity = 10.0
        newImage.add_layer(LyleLay2, 0) 
        LyleLay3 = convoLay.copy()  
        LyleLay3.mode = VALUE_MODE   
        LyleLay3.name = " 5% Lyle Layer3 " 
        LyleLay3.opacity = 5.0      
        newImage.add_layer(LyleLay3, 0) 
        if freakflag:
            FXLayer3.mode  = GRAIN_MERGE_MODE
        pdb.gimp_item_set_visible(visibLay, 0)

    elif ModeSet == 3:     ###########################################################
        if embflag:
            FXLayer1.mode = GRAIN_MERGE_MODE
        if cboflag:
            pdb.gimp_image_remove_layer(newImage, FXLayer2) 
            FXLayer2 =   origBG.copy()
            FXLayer2.name = 'GraficBoost  B0'
            FXLayer2.mode = GRAIN_MERGE_MODE
            FXLayer2.opacity = 25.0 
            newImage.add_layer(FXLayer2, 0)
            if Gmic176 or Gmic179:
                pdb.plug_in_gmic(newImage, FXLayer2, 1,    # 1=input only active layer
                "-v - -gimp_graphic_boost4 1.25,2,0,0.15,14,0,1,0.5,0.45,2,0,1,0,1,1,1,0.5,0.45,1")
            if Gmic200:
                pdb.plug_in_gmic2(newImage, FXLayer2, 1,    # 1=input only active layer
                "-v - -fx_graphic_boost4 1.25,2,0,0.15,14,0,1,0.5,0.45,2,0,1,0,1,1,1,0.5,0.45,1")
            if Gmic220:
                pdb.plug_in_gmic_qt(newImage, FXLayer2, 1, 0,    # 1=input only active layer
                "-v - -fx_graphic_boost4 1.25,2,0,0.15,14,0,1,0.5,0.45,2,0,1,0,1,1,1,0.5,0.45,1")
            FXLayer2a = origBG.copy()
            FXLayer2a.name = 'ChromaBoost B1'
            FXLayer2a.mode = GRAIN_MERGE_MODE
            FXLayer2a.opacity = 50.0 
            newImage.add_layer(FXLayer2a, 0)  
            if Gmic176 or Gmic179:
                pdb.plug_in_gmic(newImage, FXLayer2a, 1,    # 1=input only active layer
                "-v - -gimp_boost_chroma 50.0,0,0")
            if Gmic200:
                pdb.plug_in_gmic2(newImage, FXLayer2a, 1,    # 1=input only active layer
                "-v - -fx_boost_chroma 50.0,0,0")
            if Gmic220:
                pdb.plug_in_gmic_qt(newImage, FXLayer2a, 1, 0,    # 1=input only active layer
                "-v - -fx_boost_chroma 50.0,0,0")
            pdb.gimp_item_set_visible(FXLayer2, 1)
            pdb.gimp_item_set_visible(FXLayer2a, 1)            
        if freakflag:
            FXLayer3.mode =  SOFTLIGHT_MODE
            if Gmic176 or Gmic179:
                pdb.plug_in_gmic(newImage, FXLayer3, 1,    # 1=input only active layer
                "-v - -gimp_boost_fade 9.6,0")        
            if Gmic200:
                pdb.plug_in_gmic2(newImage, FXLayer3, 1,    # 1=input only active layer
                "-v - -fx_boost_fade 9.6,0")
        if not lyleflag:
            LyleLay = convoLay.copy()
            LyleLay.mode = VALUE_MODE
            LyleLay.name = "Lyle Layer"
            LyleLay.opacity = 25.0 
            newImage.add_layer(LyleLay, 0)
            pdb.gimp_item_set_visible(LyleLay, 1)
        visibLay.mode = NORMAL_MODE        
        pdb.gimp_image_remove_layer(newImage, colorLay)
        pdb.gimp_image_remove_layer(newImage, lightLay)
        pdb.gimp_image_remove_layer(newImage, convoLay)
        pdb.gimp_image_raise_layer_to_top(newImage, LyleLay)
        LyleLay.opacity = 25.0   
     
    elif ModeSet == 4:     ###########################################################  
        if embflag:    
            pdb.gimp_image_remove_layer(newImage, FXLayer1)
        if cboflag:
            pdb.gimp_image_remove_layer(newImage, FXLayer2)
        if freakflag:
            pdb.gimp_image_remove_layer(newImage, FXLayer3)
        if lyleflag:
            pdb.gimp_image_remove_layer(newImage, LyleLay)
        pdb.gimp_image_remove_layer(newImage, colorLay)
        pdb.gimp_image_remove_layer(newImage, lightLay)        
        pdb.gimp_image_raise_layer_to_top(newImage, convoLay)        
        pdb.gimp_image_set_active_layer(newImage, convoLay)        
        if Gmic176:
            pdb.plug_in_gmic(newImage, convoLay, 1,    # 1=input only active layer
            "-v - -gimp_bwrecolorize 0,0,0,0,0,0,0,8,255,35,35,255,28,169,50,255,158,137,189,255,242,162,186,255,63,55,229,255,231,59,230,255,157,94,49,255,218,196,39,255,0")
        if Gmic179:
            pdb.plug_in_gmic(newImage, convoLay, 1,    # 1=input only active layer
            "-v - -gimp_autofill_lineart 90,1,8,0,0")
        if Gmic200:
            pdb.plug_in_gmic2(newImage, convoLay, 1,    # 1=input only active layer
            "-v - -fx_autofill_lineart 90,1,8,0,0")
        if Gmic220:
            pdb.plug_in_gmic_qt(newImage, convoLay, 1, 0,    # 1=input only active layer
            "-v - -fx_autofill_lineart 90,1,8,0,0")
        artLay = pdb.gimp_image_get_active_layer(newImage)
        pdb.gimp_item_set_name(artLay, 'Art')
        pdb.gimp_image_raise_layer_to_top(newImage, artLay)
        pdb.gimp_image_raise_layer_to_top(newImage, origBG)
        artLay.mode = OVERLAY_MODE
        origBG.mode = OVERLAY_MODE

    elif ModeSet == 5:     ###########################################################
        if embflag:    
            pdb.gimp_image_remove_layer(newImage, FXLayer1)
        if cboflag:
            pdb.gimp_image_remove_layer(newImage, FXLayer2)
        if freakflag:
            pdb.gimp_image_remove_layer(newImage, FXLayer3)
        if lyleflag:
            pdb.gimp_image_remove_layer(newImage, LyleLay)
        pdb.gimp_image_remove_layer(newImage, colorLay)
        pdb.gimp_image_remove_layer(newImage, lightLay)        
        pdb.gimp_image_raise_layer_to_top(newImage, convoLay)        
        pdb.gimp_image_set_active_layer(newImage, convoLay)        
        if Gmic176:
            pdb.plug_in_gmic(newImage, convoLay, 1,    # 1=input only active layer
            "-v - -gimp_bwrecolorize 0,0,0,0,0,0,0,8,255,35,35,255,28,169,50,255,158,137,189,255,242,162,186,255,63,55,229,255,231,59,230,255,157,94,49,255,218,196,39,255,0")
        if Gmic179:
            pdb.plug_in_gmic(newImage, convoLay, 1,    # 1=input only active layer
            "-v - -gimp_autofill_lineart 90,1,8,0,0")
        if Gmic200:
            pdb.plug_in_gmic2(newImage, convoLay, 1,    # 1=input only active layer
            "-v - -fx_autofill_lineart 90,1,8,0,0")
        if Gmic220:
            pdb.plug_in_gmic_qt(newImage, convoLay, 1, 0,    # 1=input only active layer
            "-v - -fx_autofill_lineart 90,1,8,0,0")
        artLay = pdb.gimp_image_get_active_layer(newImage)
        pdb.gimp_item_set_name(artLay, 'Art')
        pdb.gimp_image_raise_layer_to_top(newImage, origBG)
        pdb.gimp_image_raise_layer_to_top(newImage, artLay)
        artLay.mode = GRAIN_MERGE_MODE
        origBG.mode = OVERLAY_MODE
########################################################### END PRESETS      

    # scale image back to original
    pdb.gimp_image_scale(newImage, width, height)

    # send new image to display    
    pdb.gimp_display_new (newImage)    
    
    # Close the undo group ?
    pdb.gimp_displays_flush
    pdb.gimp_context_pop()
    
    return(BA_Flamboyance5aqt)

# This is the plugin registration function
register(
    "BA_Flamboyance5aqt",    
    "Lyle's Flamboyance needs at least Gmic 1.7.6 \nFor a loose pattern lower Process width \nTo tighten raise process width",
    "automates a Flamboyance play published by Lylejk on gimpchat.com",
    "animicule@gimpchat.com", 
    "Brian Andersen ", 
    "Feb 23, 2016",
    "BA Flamboyance v5aqt", 
    "RGB*", 
    [
      (PF_IMAGE, "image", "Input image", None),
      (PF_DRAWABLE, "idrawable", "Input drawable", None),
      (PF_OPTION, "Gmic", "Select your G'mic version --->", 3, ("1.76-8", "1.7.9", "2.0.0", "2.2.3")),
      (PF_ADJUSTMENT, "intensity", "Convolutions (6 or 7) 1-150", 6, (1,150,1)),
      (PF_TOGGLE, "doublesize", "Doubles Process width (if<>0)", False),
      (PF_OPTION, "targetwidth", "Process Width     0=Subject Width", 0, ("0", "250", "500", "750", "1000", "1250", 
                "1500", "1750", "2000", "2250", "2500", "2750", "3000", "3250","3500","3750","4000" )),      
      (PF_TOGGLE, "lyleflag",   "Add Lyle's Secret Layer to Top", True),
      (PF_TOGGLE, "lyleflag2",  "Add an effect layer to very top", False),
      (PF_TOGGLE, "freakflag",  "Boost/Fade     Fade=0    Boost=4", False),
      (PF_TOGGLE, "cboflag",    "Boost       Chroma=0  Graphic=2", False),
      (PF_TOGGLE, "embflag",    "Emboss         Low=0       High=1", False),
      (PF_SLIDER, "fxset", "Effect Tweaks (add values)", 0, (0,7,1)), 
      (PF_SLIDER, "modeset", "Presets 0=off 1-5 may override", 0, (0,5,1)),
      
    ], 
    [
      (PF_DRAWABLE, "odrawable", "Output drawable", None),  
    ],
    BA_Flamboyance5aqt,
    menu="<Image>/Filters/Brian/",
    )

main()
